function [Ceqdef,Jacdef] = DefReact_Comb(nvar,into,colind,scl,def)

%
% Written by Julian Straus, Trondheim 09.12.2018
% 
% This function defines the definition values in the reaction
% section of the simple ammonia loop. It can be modified to define the
% flowsheet differently. The definitions in this file are empty.
%
% It is similar to the file DefReact_empty in the folder
%       "Prog.8 Full Order New Scaling\Definition Files"
% and is used for the combined flowsheet.
%
% The input of this function is given by
%       nvar:   Total number of variables.
%
%       into:   Input values to the unit operation defined in the
%               flowsheet.
%
%       colind: Indexes of the columns i the Jacobian.
%
% The main output is defined as
%       Ceqdef: Cells containing the equality constraints of the
%               definitions.
%
%       Jacdef: Cells containing the rows of the Jacobian defined by the
%               definitions.
%
% The necessary structures and cells are defined as
%       scl:    Scaling factors of the system defined in cells representing
%               the unit operations defined in par.ReactSec.
%
%       def:    Defined stream values, e.g pressure and composition for all
%               inlets and the pressure of the outlets or the flow of the
%               inlets.

% Predefinition of the returning cells.
Jacdef = cell(size(into));
Ceqdef = Jacdef;